Skip to main content Crate rustc_std_workspace_core Copy item path Source alloc Memory allocation APIs any Utilities for dynamic typing or type reflection. arch SIMD and vendor intrinsics module. array Utilities for the array primitive type. ascii Operations on ASCII strings and characters. borrow Utilities for working with borrowed data. cell Shareable mutable containers. char Utilities for the char primitive type. clone The Clone trait for types that cannot be ‘implicitly copied’. cmp Utilities for comparing and ordering values. convert Traits for conversions between types. default The Default trait for types with a default value. error Interfaces for working with Errors. f32 Constants for the f32 single-precision floating point type. f64 Constants for the f64 double-precision floating point type. ffi Platform-specific types, as defined by C. fmt Utilities for formatting and printing strings. future Asynchronous basic functionality. hash Generic hashing support. hint Hints to compiler that affects how code should be emitted or optimized. i8 Deprecation planned Redundant constants module for the i8 primitive type . i16 Deprecation planned Redundant constants module for the i16 primitive type . i32 Deprecation planned Redundant constants module for the i32 primitive type . i64 Deprecation planned Redundant constants module for the i64 primitive type . i128 Deprecation planned Redundant constants module for the i128 primitive type . isize Deprecation planned Redundant constants module for the isize primitive type . iter Composable external iteration. marker Primitive traits and types representing basic properties of types. mem Basic functions for dealing with memory, values, and types. net Networking primitives for IP communication. num Numeric traits and functions for the built-in numeric types. ops Overloadable operators. option Optional values. panic Panic support in core. pin Types that pin data to a location in memory. prelude The core prelude primitive This module reexports the primitive types to allow usage that is not
possibly shadowed by other declared types. ptr Manually manage memory through raw pointers. range Replacement range types result Error handling with the Result type. slice Slice management and manipulation. str String manipulation. sync Synchronization primitives task Types and Traits for working with asynchronous tasks. time Temporal quantification. u8 Deprecation planned Redundant constants module for the u8 primitive type . u16 Deprecation planned Redundant constants module for the u16 primitive type . u32 Deprecation planned Redundant constants module for the u32 primitive type . u64 Deprecation planned Redundant constants module for the u64 primitive type . u128 Deprecation planned Redundant constants module for the u128 primitive type . usize Deprecation planned Redundant constants module for the usize primitive type . async_iter Experimental Composable asynchronous iteration. autodiff Experimental This module provides support for automatic differentiation. For precise information on
differences between the autodiff_forward and autodiff_reverse macros and how to
use them, see their respective documentation. bstr Experimental The ByteStr type and trait implementations. contracts Experimental Unstable module containing the unstable contracts lang items and attribute macros. f16 Experimental Constants for the f16 half-precision floating point type. f128 Experimental Constants for the f128 quadruple-precision floating point type. field Experimental Field Reflection from Experimental Unstable module containing the unstable From derive macro. index Experimental Helper types for indexing slices. intrinsics Experimental Compiler intrinsics. io Experimental Traits, helpers, and type definitions for core I/O functionality. offload Experimental This module provides support for gpu offloading. For technical details regarding the offload_kernel
and how to use it, see their respective documentation. os Experimental OS-specific functionality. panicking Experimental Panic support for core pat Experimental Helper module for exporting the pattern_type macro process Experimental A module for working with processes. profiling Experimental Profiling markers for compiler instrumentation. random Experimental Random value generation. simd Experimental Portable SIMD module. ub_checks Experimental Provides the assert_unsafe_precondition macro as well as some utility functions that cover
common preconditions. unsafe_binder Experimental Operators used to turn types into unsafe binders and back. assert Asserts that a boolean expression is true at runtime. assert_eq Asserts that two expressions are equal to each other (using PartialEq ). assert_matches Asserts that an expression matches the provided pattern. assert_ne Asserts that two expressions are not equal to each other (using PartialEq ). cfg Evaluates boolean combinations of configuration flags at compile-time. cfg_select Selects code at compile-time based on cfg predicates. column Expands to the column number at which it was invoked. compile_error Causes compilation to fail with the given error message when encountered. concat Concatenates literals into a static string slice. debug_assert Asserts that a boolean expression is true at runtime. debug_assert_eq Asserts that two expressions are equal to each other. debug_assert_matches Asserts that an expression matches the provided pattern. debug_assert_ne Asserts that two expressions are not equal to each other. env Inspects an environment variable at compile time. file Expands to the file name in which it was invoked. format_args Constructs parameters for the other string-formatting macros. include Parses a file as an expression or an item according to the context. include_bytes Includes a file as a reference to a byte array. include_str Includes a UTF-8 encoded file as a string. line Expands to the line number on which it was invoked. matches Returns whether the given expression matches the provided pattern. module_path Expands to a string that represents the current module path. option_env Optionally inspects an environment variable at compile time. panic Panics the current thread. stringify Stringifies its arguments. todo Indicates unfinished code. try Deprecated Unwraps a result or propagates its error. unimplemented Indicates unimplemented code by panicking with a message of “not implemented”. unreachable Indicates unreachable code. write Writes formatted data into a buffer. writeln Writes formatted data into a buffer, with a newline appended. assert_unsafe_precondition Experimental Checks that the preconditions of an unsafe function are followed. concat_bytes Experimental Concatenates literals into a byte slice. const_format_args Experimental Same as format_args , but can be used in some const contexts. log_syntax Experimental Prints passed tokens into the standard output. pattern_type Experimental Creates a pattern type. trace_macros Experimental Enables or disables tracing functionality used for debugging other macros. derive Attribute macro used to apply derive macros.