#[non_exhaustive]pub struct Chain<T, U> { /* private fields */ }๐ฌThis is a nightly-only experimental API. (
core_io)Expand description
Implementations
Sourceimpl<T, U> Chain<T, U>
impl<T, U> Chain<T, U>
1.20.0 ยท Sourcepub fn into_inner(self) -> (T, U)
pub fn into_inner(self) -> (T, U)
Consumes the Chain, returning the wrapped readers.
Examples
use std::io;
use std::io::prelude::*;
use std::fs::File;
fn main() -> io::Result<()> {
let mut foo_file = File::open("foo.txt")?;
let mut bar_file = File::open("bar.txt")?;
let chain = foo_file.chain(bar_file);
let (foo_file, bar_file) = chain.into_inner();
Ok(())
}1.20.0 ยท Sourcepub fn get_ref(&self) -> (&T, &U)
pub fn get_ref(&self) -> (&T, &U)
Gets references to the underlying readers in this Chain.
Care should be taken to avoid modifying the internal I/O state of the
underlying readers as doing so may corrupt the internal state of this
Chain.
Examples
use std::io;
use std::io::prelude::*;
use std::fs::File;
fn main() -> io::Result<()> {
let mut foo_file = File::open("foo.txt")?;
let mut bar_file = File::open("bar.txt")?;
let chain = foo_file.chain(bar_file);
let (foo_file, bar_file) = chain.get_ref();
Ok(())
}1.20.0 ยท Sourcepub fn get_mut(&mut self) -> (&mut T, &mut U)
pub fn get_mut(&mut self) -> (&mut T, &mut U)
Gets mutable references to the underlying readers in this Chain.
Care should be taken to avoid modifying the internal I/O state of the
underlying readers as doing so may corrupt the internal state of this
Chain.
Examples
use std::io;
use std::io::prelude::*;
use std::fs::File;
fn main() -> io::Result<()> {
let mut foo_file = File::open("foo.txt")?;
let mut bar_file = File::open("bar.txt")?;
let mut chain = foo_file.chain(bar_file);
let (foo_file, bar_file) = chain.get_mut();
Ok(())
}Trait Implementations